<?php
/**
 * Maps for off canvas button element.
 *
 * @package Elements.
 */

if ( ! defined( 'CHESHALO_THEME_DIR' ) ) {
	exit( 'No direct script access allowed' );
}

if ( ! function_exists( 'cheshalo_get_vc_map_off_canvas_btn' ) ) {
	/**
	 * Displays the shortcode settings fields in the admin.
	 */
	function cheshalo_get_vc_map_off_canvas_btn() {
		return array(
			'base'        => 'cheshalo_off_canvas_btn',
			'name'        => esc_html__( 'Off canvas column button', 'cheshalo' ),
			'description' => esc_html__( 'Button for off canvas column', 'cheshalo' ),
			'category'    => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Theme elements', 'cheshalo' ) ),
			'icon'        => CHESHALO_ASSETS . '/images/vc-icon/off-canvas-column-button.svg',
			'params'      => array(
				array(
					'type'       => 'cheshalo_css_id',
					'param_name' => 'cheshalo_css_id',
				),
				/**
				 * General settings.
				 */
				array(
					'param_name' => 'button_text',
					'type'       => 'textfield',
					'heading'    => esc_html__( 'Button text', 'cheshalo' ),
					'std'        => 'Show column',
				),
				array(
					'param_name'       => 'sticky',
					'type'             => 'cheshalo_switch',
					'heading'          => esc_html__( 'Sticky', 'cheshalo' ),
					'hint'             => esc_html__( 'Make the off canvas sidebar button sticky.', 'cheshalo' ),
					'true_state'       => 'yes',
					'false_state'      => 'no',
					'std'              => 'no',
					'edit_field_class' => 'vc_col-sm-12 vc_column',
				),
				/**
				 * Icon settings.
				 */
				array(
					'param_name' => 'icon_style_section',
					'type'       => 'cheshalo_title_divider',
					'title'      => esc_html__( 'Icon', 'cheshalo' ),
					'group'      => esc_html__( 'Style', 'cheshalo' ),
				),
				array(
					'param_name'       => 'icon_type',
					'type'             => 'cheshalo_dropdown',
					'heading'          => esc_html__( 'Type', 'cheshalo' ),
					'std'              => 'default',
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-12 vc_column',
					'value'            => array(
						esc_html__( 'Without icon', 'cheshalo' ) => 'without',
						esc_html__( 'Default', 'cheshalo' ) => 'default',
						esc_html__( 'Custom image', 'cheshalo' ) => 'custom',
					),
				),
				array(
					'param_name'       => 'img_id',
					'type'             => 'attach_image',
					'heading'          => esc_html__( 'Image', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-12 vc_column',
					'dependency'       => array(
						'element' => 'icon_type',
						'value'   => array( 'custom' ),
					),
				),
				array(
					'param_name'       => 'img_size',
					'type'             => 'textfield',
					'heading'          => esc_html__( 'Image size', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-12 vc_column',
					'hint'             => esc_html__( 'Enter image size. Example: \'thumbnail\', \'medium\', \'large\', \'full\' or other sizes defined by current theme. Alternatively enter image size in pixels: 200x100 (Width x Height). Leave empty to use \'20x20\' size.', 'cheshalo' ),
					'dependency'       => array(
						'element' => 'icon_type',
						'value'   => array( 'custom' ),
					),
				),
				// Design Options tab.
				array(
					'type'       => 'css_editor',
					'heading'    => esc_html__( 'CSS box', 'cheshalo' ),
					'param_name' => 'css',
					'group'      => esc_html__( 'Design Options', 'js_composer' ),
				),
				cheshalo_get_vc_responsive_spacing_map(),

				/**
				 * Advanced tab.
				 */
				cheshalo_get_vc_responsive_visible_map( 'responsive_tabs_hide' ),
				cheshalo_get_vc_responsive_visible_map( 'wd_hide_on_desktop' ),
				cheshalo_get_vc_responsive_visible_map( 'wd_hide_on_tablet' ),
				cheshalo_get_vc_responsive_visible_map( 'wd_hide_on_mobile' ),

				// Width option (with dependency Columns option, responsive).
				cheshalo_get_responsive_dependency_width_map( 'responsive_tabs' ),
				cheshalo_get_responsive_dependency_width_map( 'width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'width_mobile' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_mobile' ),
			),
		);
	}
}
