<?php if ( ! defined( 'CHESHALO_THEME_DIR' ) ) {
	exit( 'No direct script access allowed' );}
/**
* ------------------------------------------------------------------------------------------------
* Product filters
* ------------------------------------------------------------------------------------------------
*/
if ( ! function_exists( 'cheshalo_get_vc_map_product_filters' ) ) {
	function cheshalo_get_vc_map_product_filters() {
		$title_typography = cheshalo_get_typography_map(
			array(
				'key'      => 'title_typography',
				'selector' => '{{WRAPPER}} .wd-pf-title .title-text',
				'group'    => esc_html__( 'Style', 'cheshalo' ),
			)
		);

		return array(
			'name'                    => esc_html__( 'Product filters', 'cheshalo' ),
			'base'                    => 'cheshalo_product_filters',
			'class'                   => '',
			'category'                => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Theme elements', 'cheshalo' ) ),
			'description'             => esc_html__( 'Add filters by category, attribute or price', 'cheshalo' ),
			'icon'                    => CHESHALO_ASSETS . '/images/vc-icon/product-filter.svg',
			'as_parent'               => array( 'only' => 'cheshalo_filter_categories, cheshalo_filters_attribute, cheshalo_filters_price_slider, cheshalo_stock_status, cheshalo_filters_orderby' ),
			'content_element'         => true,
			'show_settings_on_create' => true,
			'params'                  => array(
				/**
				 * General tab.
				 */
				array(
					'type'       => 'cheshalo_css_id',
					'param_name' => 'cheshalo_css_id',
				),
				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Submit form on', 'cheshalo' ),
					'param_name'       => 'submit_form_on',
					'value'            => array(
						esc_html__( 'Button click', 'cheshalo' ) => 'click',
						esc_html__( 'Dropdown select', 'cheshalo' ) => 'select',
					),
					'std'              => 'click',
					'edit_field_class' => 'vc_col-sm-12 vc_column',
				),
				array(
					'type'             => 'cheshalo_switch',
					'heading'          => esc_html__( 'Show selected values in dropdown', 'cheshalo' ),
					'param_name'       => 'show_selected_values',
					'true_state'       => 'yes',
					'false_state'      => 'no',
					'default'          => 'yes',
					'edit_field_class' => 'vc_col-sm-12 vc_column',
				),
				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Show dropdown on', 'cheshalo' ),
					'param_name'       => 'show_dropdown_on',
					'value'            => array(
						esc_html__( 'Hover', 'cheshalo' ) => 'hover',
						esc_html__( 'Click', 'cheshalo' ) => 'click',
					),
					'std'              => 'click',
					'edit_field_class' => 'vc_col-sm-12 vc_column',
				),
				array(
					'type'       => 'textfield',
					'heading'    => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint'       => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' ),
				),

				/**
				 * Style tab.
				 */

				/**
				 * General settings.
				 */
				array(
					'type'       => 'cheshalo_title_divider',
					'title'      => esc_html__( 'General', 'cheshalo' ),
					'param_name' => 'title_style_section',
					'group'      => esc_html__( 'Style', 'cheshalo' ),
					'holder'     => 'div',
				),
				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Style', 'cheshalo' ),
					'param_name'       => 'style',
					'value'            => array(
						esc_html__( 'Simplified', 'cheshalo' ) => 'simplified',
						esc_html__( 'Form', 'cheshalo' )       => 'form',
						esc_html__( 'Form underlined', 'cheshalo' ) => 'form-underlined',
					),
					'std'              => 'form',
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-12 vc_column',
				),
				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Display grid', 'cheshalo' ),
					'param_name'       => 'display_grid',
					'value'            => array(
						esc_html__( 'Stretch', 'cheshalo' ) => 'stretch',
						esc_html__( 'Inline', 'cheshalo' ) => 'inline',
						esc_html__( 'Number', 'cheshalo' ) => 'number',
					),
					'std'              => 'stretch',
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-12 vc_column',
				),
				array(
					'type'             => 'wd_slider',
					'heading'          => esc_html__( 'Columns', 'cheshalo' ),
					'param_name'       => 'display_grid_col',
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'selectors'        => array(),
					'devices'          => array(
						'desktop' => array(
							'unit'  => '-',
							'value' => 4,
						),
						'tablet'  => array(
							'unit'  => '-',
							'value' => 0,
						),
						'mobile'  => array(
							'unit'  => '-',
							'value' => 0,
						),
					),
					'range'            => array(
						'-' => array(
							'min'  => 1,
							'max'  => 12,
							'step' => 1,
						),
					),
					'dependency'       => array(
						'element' => 'display_grid',
						'value'   => array( 'number' ),
					),
					'edit_field_class' => 'vc_col-sm-12 vc_column',
				),
				array(
					'type'             => 'wd_select',
					'heading'          => esc_html__( 'Space between', 'cheshalo' ),
					'param_name'       => 'space_between',
					'style'            => 'select',
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'selectors'        => array(),
					'devices'          => array(
						'desktop' => array(
							'value' => '10',
						),
						'tablet'  => array(
							'value' => '10',
						),
						'mobile'  => array(
							'value' => '10',
						),
					),
					'value'            => array(
						esc_html__( '0 px', 'cheshalo' )  => '0',
						esc_html__( '2 px', 'cheshalo' )  => '2',
						esc_html__( '6 px', 'cheshalo' )  => '6',
						esc_html__( '10 px', 'cheshalo' ) => '10',
						esc_html__( '20 px', 'cheshalo' ) => '20',
						esc_html__( '30 px', 'cheshalo' ) => '30',
					),
					'edit_field_class' => 'vc_col-sm-12 vc_column',
				),
				array(
					'type'       => 'cheshalo_button_set',
					'heading'    => esc_html__( 'Color Scheme', 'cheshalo' ),
					'param_name' => 'cheshalo_color_scheme',
					'group'      => esc_html__( 'Style', 'cheshalo' ),
					'value'      => array(
						esc_html__( 'Inherit', 'cheshalo' ) => '',
						esc_html__( 'Light', 'cheshalo' ) => 'light',
						esc_html__( 'Dark', 'cheshalo' )  => 'dark',
					),
				),

				/**
				 * Title settings.
				 */
				array(
					'type'       => 'cheshalo_title_divider',
					'title'      => esc_html__( 'Title', 'cheshalo' ),
					'param_name' => 'title_style_section',
					'group'      => esc_html__( 'Style', 'cheshalo' ),
					'holder'     => 'div',
				),
				array(
					'type'             => 'wd_colorpicker',
					'heading'          => esc_html__( 'Idle color', 'cheshalo' ),
					'param_name'       => 'title_idle_color',
					'selectors'        => array(
						'{{WRAPPER}} .title-text' => array(
							'color: {{VALUE}};',
						),
					),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'wd_colorpicker',
					'heading'          => esc_html__( 'Hover color', 'cheshalo' ),
					'param_name'       => 'title_hover_color',
					'selectors'        => array(
						'{{WRAPPER}} .wd-pf-checkboxes:hover .title-text, {{WRAPPER}} .wd-pf-checkboxes.wd-opened .title-text' => array(
							'color: {{VALUE}};',
						),
					),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'heading'          => esc_html__( 'Border color', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'wd_colorpicker',
					'param_name'       => 'form_brd_color',
					'selectors'        => array(
						'{{WRAPPER}} .wd-product-filters' => array(
							'--wd-form-brd-color: {{VALUE}};',
						),
					),
					'dependency'       => array(
						'element' => 'style',
						'value'   => array( 'form', 'form-underlined' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'heading'          => esc_html__( 'Border color focus', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'wd_colorpicker',
					'param_name'       => 'form_brd_color_focus',
					'selectors'        => array(
						'{{WRAPPER}} .wd-product-filters' => array(
							'--wd-form-brd-color-focus: {{VALUE}};',
						),
					),
					'dependency'       => array(
						'element' => 'style',
						'value'   => array( 'form', 'form-underlined' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'heading'          => esc_html__( 'Background color', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'wd_colorpicker',
					'param_name'       => 'form_bg',
					'selectors'        => array(
						'{{WRAPPER}} .wd-product-filters' => array(
							'--wd-form-bg: {{VALUE}};',
						),
					),
					'dependency'       => array(
						'element' => 'style',
						'value'   => array( 'form' ),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				$title_typography['font_family'],
				$title_typography['font_size'],
				$title_typography['font_weight'],
				$title_typography['text_transform'],
				$title_typography['font_style'],
				$title_typography['line_height'],
				/**
				 * Design Options tab.
				 */
				array(
					'type'       => 'css_editor',
					'heading'    => esc_html__( 'CSS box', 'cheshalo' ),
					'param_name' => 'css',
					'group'      => esc_html__( 'Design Options', 'js_composer' ),
				),
				cheshalo_get_vc_responsive_spacing_map(),

				// Width option (with dependency Columns option, responsive).
				cheshalo_get_responsive_dependency_width_map( 'responsive_tabs' ),
				cheshalo_get_responsive_dependency_width_map( 'width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'width_mobile' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_mobile' ),
			),
			'js_view'                 => 'VcColumnView',
		);
	}
}

if ( ! function_exists( 'cheshalo_get_vc_map_filter_categories' ) ) {
	function cheshalo_get_vc_map_filter_categories() {
		return array(
			'name'            => esc_html__( 'Filter categories', 'cheshalo' ),
			'base'            => 'cheshalo_filter_categories',
			'as_child'        => array( 'only' => 'cheshalo_product_filters' ),
			'content_element' => true,
			'category'        => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Theme elements', 'cheshalo' ) ),
			'icon'            => CHESHALO_ASSETS . '/images/vc-icon/product-filter-categories.svg',
			'params'          => array(
				array(
					'type'       => 'cheshalo_title_divider',
					'holder'     => 'div',
					'title'      => esc_html__( 'General options', 'cheshalo' ),
					'param_name' => 'general_divider',
				),
				array(
					'type'             => 'textfield',
					'heading'          => esc_html__( 'Title', 'cheshalo' ),
					'param_name'       => 'title',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Order by', 'cheshalo' ),
					'param_name'       => 'order_by',
					'value'            => array(
						esc_html__( 'Name', 'cheshalo' ) => 'name',
						esc_html__( 'ID', 'cheshalo' ) => 'ID',
						esc_html__( 'Slug', 'cheshalo' ) => 'slug',
						esc_html__( 'Count', 'cheshalo' ) => 'count',
						esc_html__( 'Category order', 'cheshalo' ) => 'order',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'cheshalo_switch',
					'heading'          => esc_html__( 'Show hierarchy', 'cheshalo' ),
					'param_name'       => 'hierarchical',
					'true_state'       => 1,
					'false_state'      => 0,
					'default'          => 1,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'cheshalo_switch',
					'heading'          => esc_html__( 'Hide empty categories', 'cheshalo' ),
					'param_name'       => 'hide_empty',
					'true_state'       => 1,
					'false_state'      => 0,
					'default'          => 0,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'cheshalo_switch',
					'heading'          => esc_html__( 'Show current category ancestors', 'cheshalo' ),
					'param_name'       => 'show_categories_ancestors',
					'hint'             => esc_html__( 'If you visit category Man, for example, only man\'s subcategories will be shown in the page title like T-shirts, Coats, Shoes etc.', 'cheshalo' ),
					'true_state'       => 1,
					'false_state'      => 0,
					'default'          => 0,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'       => 'cheshalo_title_divider',
					'holder'     => 'div',
					'title'      => esc_html__( 'Extra options', 'cheshalo' ),
					'param_name' => 'extra_divider',
				),
				array(
					'type'             => 'textfield',
					'heading'          => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name'       => 'el_class',
					'hint'             => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
			),
			array(
				'type' => 'cheshalo_switch',
				'heading' => esc_html__( 'Show labels', 'cheshalo' ),
				'param_name' => 'labels',
				'true_state' => 1,
				'false_state' => 0,
				'default' => 1,
				'edit_field_class' => 'vc_col-sm-6 vc_column',
			),
			array(
				'type' => 'cheshalo_title_divider',
				'holder' => 'div',
				'title' => esc_html__( 'Extra options', 'cheshalo' ),
				'param_name' => 'extra_divider'
			),
		);
	}
}

if ( ! function_exists( 'cheshalo_get_vc_map_filters_attribute' ) ) {
	function cheshalo_get_vc_map_filters_attribute() {
		$attribute_array = array( '' => '' );

		if ( function_exists( 'wc_get_attribute_taxonomies' ) ) {
			$attribute_taxonomies = wc_get_attribute_taxonomies();

			if ( $attribute_taxonomies ) {
				foreach ( $attribute_taxonomies as $tax ) {
					$attribute_array[ $tax->attribute_name ] = $tax->attribute_name;
				}
			}
		}

		return array(
			'name'            => esc_html__( 'Filter attribute', 'cheshalo' ),
			'base'            => 'cheshalo_filters_attribute',
			'as_child'        => array( 'only' => 'cheshalo_product_filters' ),
			'content_element' => true,
			'category'        => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Theme elements', 'cheshalo' ) ),
			'icon'            => CHESHALO_ASSETS . '/images/vc-icon/product-filter-atribute.svg',
			'params'          => array(
				array(
					'type'       => 'cheshalo_title_divider',
					'holder'     => 'div',
					'title'      => esc_html__( 'General options', 'cheshalo' ),
					'param_name' => 'general_divider',
				),
				array(
					'type'             => 'textfield',
					'heading'          => esc_html__( 'Title', 'cheshalo' ),
					'param_name'       => 'title',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Attribute', 'cheshalo' ),
					'param_name'       => 'attribute',
					'value'            => $attribute_array,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'autocomplete',
					'heading'          => esc_html__( 'Show in categories', 'cheshalo' ),
					'param_name'       => 'categories',
					'settings'         => array(
						'multiple' => true,
						'sortable' => true,
					),
					'save_always'      => true,
					'hint'             => esc_html__( 'Choose on which categories pages you want to display this filter. Or leave empty to show on all pages.', 'cheshalo' ),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'cheshalo_button_set',
					'heading'          => esc_html__( 'Query type', 'cheshalo' ),
					'param_name'       => 'query_type',
					'hint'             => esc_html__( 'If you select “AND”, you will be allowed to select only one attribute. In case of “OR”, you will be able to select multiple values.', 'cheshalo' ),
					'value'            => array(
						esc_html__( 'AND', 'cheshalo' ) => 'and',
						esc_html__( 'OR', 'cheshalo' ) => 'or',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Swatches size', 'cheshalo' ),
					'param_name'       => 'size',
					'value'            => array(
						esc_html__( 'Small', 'cheshalo' ) => 'small',
						esc_html__( 'Medium', 'cheshalo' ) => 'normal',
						esc_html__( 'Large', 'cheshalo' ) => 'large',
					),
					'std'              => 'normal',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Swatches shape', 'cheshalo' ),
					'param_name'       => 'shape',
					'value'            => array(
						esc_html__( 'Inherit', 'cheshalo' ) => 'inherit',
						esc_html__( 'Round', 'cheshalo' ) => 'round',
						esc_html__( 'Rounded', 'cheshalo' ) => 'rounded',
						esc_html__( 'Square', 'cheshalo' ) => 'square',
					),
					'std'              => 'inherit',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Swatch style', 'cheshalo' ),
					'param_name'       => 'swatch_style',
					'value'            => array(
						esc_html__( 'Inherit', 'cheshalo' ) => 'inherit',
						esc_html__( 'Style 1', 'cheshalo' ) => '1',
						esc_html__( 'Style 2', 'cheshalo' ) => '2',
						esc_html__( 'Style 3', 'cheshalo' ) => '3',
						esc_html__( 'Style 4', 'cheshalo' ) => '4',
					),
					'std'              => 'inherit',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'dropdown',
					'heading'          => esc_html__( 'Layout', 'cheshalo' ),
					'param_name'       => 'display',
					'value'            => array(
						esc_html__( 'List', 'cheshalo' )   => 'list',
						esc_html__( '2 columns', 'cheshalo' ) => 'double',
						esc_html__( 'Inline', 'cheshalo' ) => 'inline',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'cheshalo_switch',
					'heading'          => esc_html__( 'Show labels', 'cheshalo' ),
					'param_name'       => 'labels',
					'true_state'       => 1,
					'false_state'      => 0,
					'default'          => 1,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type' => 'cheshalo_title_divider',
					'holder' => 'div',
					'title' => esc_html__( 'Extra options', 'cheshalo' ),
					'param_name' => 'extra_divider'
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' )
				)
			),
		);
	}
}

if ( ! function_exists( 'cheshalo_get_vc_map_stock_status' ) ) {
	function cheshalo_get_vc_map_stock_status() {
		return array(
			'name'            => esc_html__( 'Stock status', 'cheshalo' ),
			'base'            => 'cheshalo_stock_status',
			'as_child'        => array( 'only' => 'cheshalo_product_filters' ),
			'content_element' => true,
			'category'        => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Theme elements', 'cheshalo' ) ),
			'icon'            => CHESHALO_ASSETS . '/images/vc-icon/product-filter-atribute.svg',
			'params'          => array(
				array(
					'type'       => 'cheshalo_title_divider',
					'holder'     => 'div',
					'title'      => esc_html__( 'General options', 'cheshalo' ),
					'param_name' => 'general_divider',
				),
				array(
					'type'             => 'textfield',
					'heading'          => esc_html__( 'Title', 'cheshalo' ),
					'param_name'       => 'title',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'cheshalo_switch',
					'heading'          => esc_html__( 'Show labels', 'cheshalo' ),
					'param_name'       => 'labels',
					'true_state'       => 1,
					'false_state'      => 0,
					'default'          => 1,
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'type'             => 'cheshalo_switch',
					'heading'          => esc_html__( 'On Sale filter', 'cheshalo' ),
					'param_name'       => 'onsale',
					'true_state'       => 1,
					'false_state'      => 0,
					'default'          => 1,
					'edit_field_class' => 'vc_col-sm-4 vc_column',
				),
				array(
					'type'             => 'cheshalo_switch',
					'heading'          => esc_html__( 'In Stock filter', 'cheshalo' ),
					'param_name'       => 'instock',
					'true_state'       => 1,
					'false_state'      => 0,
					'default'          => 1,
					'edit_field_class' => 'vc_col-sm-4 vc_column',
				),
				array(
					'type'             => 'cheshalo_switch',
					'heading'          => esc_html__( 'On backorder filter', 'cheshalo' ),
					'param_name'       => 'onbackorder',
					'true_state'       => 1,
					'false_state'      => 0,
					'default'          => 1,
					'edit_field_class' => 'vc_col-sm-4 vc_column',
				),
				array(
					'type'       => 'cheshalo_title_divider',
					'holder'     => 'div',
					'title'      => esc_html__( 'Extra options', 'cheshalo' ),
					'param_name' => 'extra_divider',
				),
				array(
					'type'       => 'textfield',
					'heading'    => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint'       => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' ),
				),
			),
		);
	}
}

if ( ! function_exists( 'cheshalo_get_vc_map_filters_price_slider' ) ) {
	function cheshalo_get_vc_map_filters_price_slider() {
		return array(
			'name'            => esc_html__( 'Filter price', 'cheshalo' ),
			'base'            => 'cheshalo_filters_price_slider',
			'as_child'        => array( 'only' => 'cheshalo_product_filters' ),
			'content_element' => true,
			'category'        => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Theme elements', 'cheshalo' ) ),
			'icon'            => CHESHALO_ASSETS . '/images/vc-icon/product-filter-price.svg',
			'params'          => array(
				array(
					'type'       => 'textfield',
					'heading'    => esc_html__( 'Title', 'cheshalo' ),
					'param_name' => 'title',
				),
				array(
					'type'       => 'textfield',
					'heading'    => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint'       => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' ),
				),
			),
		);
	}
}

if ( ! function_exists( 'cheshalo_get_vc_map_filters_orderby' ) ) {
	function cheshalo_get_vc_map_filters_orderby() {
		return array(
			'name'            => esc_html__( 'Order by', 'cheshalo' ),
			'base'            => 'cheshalo_filters_orderby',
			'as_child'        => array( 'only' => 'cheshalo_product_filters' ),
			'content_element' => true,
			'category'        => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Theme elements', 'cheshalo' ) ),
			'icon'            => CHESHALO_ASSETS . '/images/vc-icon/product-filter-atribute.svg',
			'params'          => array(
				array(
					'type'       => 'textfield',
					'heading'    => esc_html__( 'Extra class name', 'cheshalo' ),
					'param_name' => 'el_class',
					'hint'       => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' ),
				),
			),
		);
	}
}

add_filter( 'vc_autocomplete_cheshalo_filters_attribute_categories_callback', 'cheshalo_productCategoryCategoryAutocompleteSuggester', 10, 1 );

add_filter( 'vc_autocomplete_cheshalo_filters_attribute_categories_render', 'cheshalo_productCategoryCategoryRenderByIdExact', 10, 1 );

// A must for container functionality, replace Wbc_Item with your base name from mapping for parent container
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
	class WPBakeryShortCode_cheshalo_product_filters extends WPBakeryShortCodesContainer {}

	class WPBakeryShortCode_cheshalo_filter_categories extends WPBakeryShortCode {}

	class WPBakeryShortCode_cheshalo_filters_attribute extends WPBakeryShortCode {}

	class WPBakeryShortCode_cheshalo_filters_price_slider extends WPBakeryShortCode {}

	class WPBakeryShortCode_cheshalo_filters_orderby extends WPBakeryShortCode {}

	class WPBakeryShortCode_cheshalo_stock_status extends WPBakeryShortCode {}
}
