<?php
/**
 * Login form map.
 *
 * @package Cheshalo
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Direct access not allowed.
}

if ( ! function_exists( 'cheshalo_get_vc_map_checkout_login_form' ) ) {
	/**
	 * Login form map.
	 */
	function cheshalo_get_vc_map_checkout_login_form() {
		$toggle_typography = cheshalo_get_typography_map(
			array(
				'key'      => 'toggle_typography',
				'group'    => esc_html__( 'Style', 'js_composer' ),
				'selector' => '{{WRAPPER}} .woocommerce-form-login-toggle > div',
			)
		);

		return array(
			'base'        => 'cheshalo_checkout_login_form',
			'name'        => esc_html__( 'Login form', 'cheshalo' ),
			'category'    => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Checkout', 'cheshalo' ), 'checkout_content' ),
			'description' => esc_html__( 'Checkout user login form', 'cheshalo' ),
			'icon'        => CHESHALO_ASSETS . '/images/vc-icon/ch-icons/ch-login-form.svg',
			'params'      => array(
				array(
					'title'      => esc_html__( 'General', 'cheshalo' ),
					'group'      => esc_html__( 'Style', 'js_composer' ),
					'type'       => 'cheshalo_title_divider',
					'param_name' => 'general_style_section',
				),
				array(
					'heading'          => esc_html__( 'Alignment', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'param_name'       => 'alignment',
					'type'             => 'cheshalo_image_select',
					'value'            => array(
						esc_html__( 'Left', 'cheshalo' )   => 'left',
						esc_html__( 'Center', 'cheshalo' ) => 'center',
						esc_html__( 'Right', 'cheshalo' )  => 'right',
					),
					'images_value'     => array(
						'center' => CHESHALO_ASSETS_IMAGES . '/settings/align/center.jpg',
						'left'   => CHESHALO_ASSETS_IMAGES . '/settings/align/left.jpg',
						'right'  => CHESHALO_ASSETS_IMAGES . '/settings/align/right.jpg',
					),
					'std'              => 'left',
					'wood_tooltip'     => true,
					'edit_field_class' => 'vc_col-sm-6 vc_column title-align',
				),
				array(
					'title'      => esc_html__( 'Toggle', 'cheshalo' ),
					'group'      => esc_html__( 'Style', 'js_composer' ),
					'type'       => 'cheshalo_title_divider',
					'param_name' => 'toggle_style_section',
				),
				$toggle_typography['font_family'],
				$toggle_typography['font_size'],
				$toggle_typography['font_weight'],
				$toggle_typography['text_transform'],
				$toggle_typography['font_style'],
				$toggle_typography['line_height'],
				array(
					'title'      => esc_html__( 'Form', 'cheshalo' ),
					'group'      => esc_html__( 'Style', 'js_composer' ),
					'type'       => 'cheshalo_title_divider',
					'param_name' => 'form_style_section',
				),
				array(
					'heading'          => esc_html__( 'Width', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'wd_slider',
					'param_name'       => 'form_width',
					'devices'          => array(
						'desktop' => array(
							'unit'  => 'px',
							'value' => 470,
						),
						'tablet' => array(
							'unit'  => 'px',
							'value' => 0,
						),
						'mobile' => array(
							'unit'  => 'px',
							'value' => 0,
						),
					),
					'range'            => array(
						'px' => array(
							'min'  => 0,
							'max'  => 1200,
							'step' => 1,
						),
						'%' => array(
							'min'  => 0,
							'max'  => 100,
							'step' => 1,
						),
					),
					'selectors'        => array(
						'{{WRAPPER}} .login.hidden-form' => array(
							'max-width: {{VALUE}}{{UNIT}};',
						),
					),
					'edit_field_class' => 'vc_col-sm-12 vc_column',
				),
				array(
					'heading'          => esc_html__( 'Background color', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'wd_colorpicker',
					'param_name'       => 'form_bg_color',
					'selectors'        => array(
						'{{WRAPPER}} .login.hidden-form' => array(
							'background-color: {{VALUE}};',
						),
					),
				),
				array(
					'heading'          => esc_html__( 'Border type', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'wd_select',
					'param_name'       => 'border_type',
					'style'            => 'select',
					'selectors'        => array(
						'{{WRAPPER}} .login.hidden-form' => array(
							'border-style: {{VALUE}};',
						),
					),
					'devices'          => array(
						'desktop' => array(
							'value' => '',
						),
					),
					'value'            => array(
						esc_html__( 'Default', 'cheshalo' ) => '',
						esc_html__( 'None', 'cheshalo' )    => 'none',
						esc_html__( 'Solid', 'cheshalo' )   => 'solid',
						esc_html__( 'Dotted', 'cheshalo' )  => 'dotted',
						esc_html__( 'Double', 'cheshalo' )  => 'double',
						esc_html__( 'Dashed', 'cheshalo' )  => 'dashed',
						esc_html__( 'Groove', 'cheshalo' )  => 'groove',
					),
				),
				array(
					'heading'    => esc_html__( 'Border width', 'cheshalo' ),
					'group'      => esc_html__( 'Style', 'cheshalo' ),
					'type'       => 'wd_dimensions',
					'param_name' => 'border_width',
					'selectors'  => array(
						'{{WRAPPER}} .login.hidden-form' => array(
							'border-top-width: {{TOP}}px;',
							'border-right-width: {{RIGHT}}px;',
							'border-bottom-width: {{BOTTOM}}px;',
							'border-left-width: {{LEFT}}px;',
						),
					),
					'devices'    => array(
						'desktop' => array(
							'unit' => 'px',
						),
					),
					'range'      => array(
						'px' => array(),
					),
					'dependency' => array(
						'element' => 'border_type',
						'value_not_equal_to' => array('', 'eyJkZXZpY2VzIjp7ImRlc2t0b3AiOnsidmFsdWUiOiJub25lIn19fQ=='),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'heading'          => esc_html__( 'Border color', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'wd_colorpicker',
					'param_name'       => 'border_color',
					'selectors'        => array(
						'{{WRAPPER}} .login.hidden-form' => array(
							'border-color: {{VALUE}};',
						),
					),
					'dependency' => array(
						'element'   => 'border_type',
						'value_not_equal_to' => array('', 'eyJkZXZpY2VzIjp7ImRlc2t0b3AiOnsidmFsdWUiOiJub25lIn19fQ=='),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),
				array(
					'heading'    => esc_html__( 'Border radius', 'cheshalo' ),
					'group'      => esc_html__( 'Style', 'cheshalo' ),
					'type'       => 'wd_dimensions',
					'param_name' => 'border_radius',
					'selectors'  => array(
						'{{WRAPPER}} .login.hidden-form' => array(
							'border-top-left-radius: {{TOP}}{{UNIT}};',
							'border-top-right-radius: {{RIGHT}}{{UNIT}};',
							'border-bottom-right-radius: {{BOTTOM}}{{UNIT}};',
							'border-bottom-left-radius: {{LEFT}}{{UNIT}};',
						),
					),
					'devices'    => array(
						'desktop' => array(
							'unit' => 'px',
						),
						'tablet' => array(
							'unit' => 'px',
						),
						'mobile' => array(
							'unit' => 'px',
						),
					),
					'range'      => array(
						'px' => array(),
					),
					'dependency' => array(
						'element' => 'border_type',
						'value_not_equal_to' => array('', 'eyJkZXZpY2VzIjp7ImRlc2t0b3AiOnsidmFsdWUiOiJub25lIn19fQ=='),
					),
				),
				array(
					'heading'    => esc_html__( 'Padding', 'cheshalo' ),
					'group'      => esc_html__( 'Style', 'cheshalo' ),
					'type'       => 'wd_dimensions',
					'param_name' => 'form_padding',
					'selectors'  => array(
						'{{WRAPPER}} .login.hidden-form' => array(
							'padding-top: {{TOP}}{{UNIT}};',
							'padding-left: {{LEFT}}{{UNIT}};',
							'padding-right: {{RIGHT}}{{UNIT}};',
							'padding-bottom: {{BOTTOM}}{{UNIT}};',
						),
					),
					'devices'    => array(
						'desktop' => array(
							'unit' => 'px',
						),
						'tablet' => array(
							'unit' => 'px',
						),
						'mobile' => array(
							'unit' => 'px',
						),
					),
					'range'      => array(
						'px' => array(),
					),
				),

				array(
					'group'      => esc_html__( 'Design Options', 'js_composer' ),
					'type'       => 'cheshalo_css_id',
					'param_name' => 'cheshalo_css_id',
				),

				array(
					'heading'    => esc_html__( 'CSS box', 'cheshalo' ),
					'group'      => esc_html__( 'Design Options', 'js_composer' ),
					'type'       => 'css_editor',
					'param_name' => 'css',
				),
				cheshalo_get_vc_responsive_spacing_map(),

				// Width option (with dependency Columns option, responsive).
				cheshalo_get_responsive_dependency_width_map( 'responsive_tabs' ),
				cheshalo_get_responsive_dependency_width_map( 'width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'width_mobile' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_mobile' ),
			),
		);
	}
}
