<?php
/**
 * Title map.
 *
 * @package Cheshalo
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Direct access not allowed.
}

if ( ! function_exists( 'cheshalo_get_vc_map_single_product_title' ) ) {
	/**
	 * Title map.
	 */
	function cheshalo_get_vc_map_single_product_title() {
		$typography = cheshalo_get_typography_map(
			array(
				'key'      => 'title',
				'selector' => 'html {{WRAPPER}}.wd-single-title .product_title',
			)
		);

		return array(
			'base'        => 'cheshalo_single_product_title',
			'name'        => esc_html__( 'Product title', 'cheshalo' ),
			'category'    => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'Single product elements', 'cheshalo' ), 'single_product' ),
			'description' => esc_html__( 'Name for the current product', 'cheshalo' ),
			'icon'        => CHESHALO_ASSETS . '/images/vc-icon/sp-icons/sp-title.svg',
			'params'      => array(
				array(
					'type'       => 'cheshalo_css_id',
					'param_name' => 'cheshalo_css_id',
				),

				array(
					'heading'    => esc_html__( 'Text alignment', 'cheshalo' ),
					'type'       => 'wd_select',
					'param_name' => 'text_alignment',
					'style'      => 'images',
					'selectors'  => array(),
					'devices'    => array(
						'desktop' => array(
							'value' => 'left',
						),
					),
					'value'      => array(
						esc_html__( 'Left', 'cheshalo' )   => 'left',
						esc_html__( 'Center', 'cheshalo' ) => 'center',
						esc_html__( 'Right', 'cheshalo' )  => 'right',
					),
					'images'     => array(
						'left'   => CHESHALO_ASSETS_IMAGES . '/settings/align/left.jpg',
						'center' => CHESHALO_ASSETS_IMAGES . '/settings/align/center.jpg',
						'right'  => CHESHALO_ASSETS_IMAGES . '/settings/align/right.jpg',
					),
				),

				$typography['font_family'],
				$typography['font_size'],
				$typography['font_weight'],
				$typography['text_transform'],
				$typography['font_style'],
				$typography['line_height'],

				array(
					'heading'          => esc_html__( 'Text color', 'cheshalo' ),
					'type'             => 'wd_colorpicker',
					'param_name'       => 'text_color',
					'selectors'        => array(
						'html {{WRAPPER}}.wd-single-title .product_title' => array(
							'color: {{VALUE}};',
						),
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'heading'    => esc_html__( 'CSS box', 'cheshalo' ),
					'group'      => esc_html__( 'Design Options', 'js_composer' ),
					'type'       => 'css_editor',
					'param_name' => 'css',
				),
				cheshalo_get_vc_responsive_spacing_map(),

				// Width option (with dependency Columns option, responsive).
				cheshalo_get_responsive_dependency_width_map( 'responsive_tabs' ),
				cheshalo_get_responsive_dependency_width_map( 'width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'width_mobile' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_mobile' ),
			),
		);
	}
}

add_filter( 'vc_autocomplete_cheshalo_single_product_title_product_id_callback', 'cheshalo_productIdAutocompleteSuggester_new', 10, 1 );
add_filter( 'vc_autocomplete_cheshalo_single_product_title_product_id_render', 'cheshalo_productIdAutocompleteRender', 10, 1 );
