<?php
/**
 * This file creates CHESHALO Banner Widget.
 *
 * @package Cheshalo
 */

if ( ! defined( 'CHESHALO_THEME_DIR' ) ) {
	exit( 'No direct script access allowed' );
};

if ( ! class_exists( 'CHESHALO_Banner_Widget' ) ) {
	/**
	 * Register widget based on VC_MAP parameters that display banner shortcode
	 */
	class CHESHALO_Banner_Widget extends WPH_Widget {

		/**
		 * This method creates these widgets.
		 */
		public function __construct() {
			if ( ! function_exists( 'cheshalo_get_banner_params' ) ) {
				return;
			};

			$secondary_font = cheshalo_get_opt( 'secondary-font' );
			$text_font      = cheshalo_get_opt( 'text-font' );
			$primary_font   = cheshalo_get_opt( 'primary-font' );

			$secondary_font_title = isset( $secondary_font[0] ) ? esc_html__( 'Secondary', 'cheshalo' ) . ' (' . $secondary_font[0]['font-family'] . ')' : esc_html__( 'Secondary', 'cheshalo' );
			$text_font_title      = isset( $text_font[0] ) ? esc_html__( 'Text', 'cheshalo' ) . ' (' . $text_font[0]['font-family'] . ')' : esc_html__( 'Text', 'cheshalo' );
			$primary_font_title   = isset( $primary_font[0] ) ? esc_html__( 'Primary', 'cheshalo' ) . ' (' . $primary_font[0]['font-family'] . ')' : esc_html__( 'Primary', 'cheshalo' );

			$this->create_widget(
				array(
					'label'       => esc_html__( 'CHESHALO Banner', 'cheshalo' ),
					'description' => esc_html__( 'Promo banner with text', 'cheshalo' ),
					'slug'        => 'cheshalo-banner',
					'fields'      => array(
						/**
						 * Image.
						 */
						array(
							'type'       => 'cheshalo_title_divider',
							'holder'     => 'div',
							'title'      => esc_html__( 'Image', 'cheshalo' ),
							'param_name' => 'image_divider',
						),
						array(
							'type'             => 'attach_image',
							'heading'          => esc_html__( 'Image', 'cheshalo' ),
							'param_name'       => 'image',
							'value'            => '',
							'hint'             => esc_html__( 'Select image from media library.', 'cheshalo' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'        => 'textfield',
							'heading'     => esc_html__( 'Image size', 'cheshalo' ),
							'param_name'  => 'img_size',
							'description' => esc_html__( 'Example: \'thumbnail\', \'medium\', \'large\', \'full\'.', 'cheshalo' ),
						),
						array(
							'type'             => 'cheshalo_slider',
							'heading'          => esc_html__( 'Banner height', 'cheshalo' ),
							'param_name'       => 'height',
							'min'              => '100',
							'max'              => '2000',
							'step'             => '1',
							'default'          => '300',
							'units'            => 'px',
							'value'            => array(
								'600' => '600',
								'500' => '500',
								'400' => '400',
								'350' => '350',
								'300' => '300',
								'250' => '250',
								'200' => '200',
								'150' => '150',
								'100' => '100',
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'hint'             => esc_html__( 'Default: 300', 'cheshalo' ),
						),
						array(
							'type'             => 'dropdown',
							'heading'          => esc_html__( 'Image Position', 'cheshalo' ),
							'param_name'       => 'image_bg_position',
							'value'            => array(
								esc_html__( 'Center', 'cheshalo' ) => 'center',
								esc_html__( 'Top', 'cheshalo' )    => 'top',
								esc_html__( 'Bottom', 'cheshalo' ) => 'bottom',
								esc_html__( 'Left', 'cheshalo' )   => 'left',
								esc_html__( 'Right', 'cheshalo' )  => 'right',
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'       => 'vc_link',
							'heading'    => esc_html__( 'Banner link', 'cheshalo' ),
							'param_name' => 'link',
							'hint'       => esc_html__( 'Enter URL if you want this banner to have a link.', 'cheshalo' ),
						),
						/**
						 * Style.
						 */
						array(
							'type'       => 'cheshalo_title_divider',
							'holder'     => 'div',
							'title'      => esc_html__( 'Style', 'cheshalo' ),
							'param_name' => 'style_divider',
						),
						array(
							'type'             => 'cheshalo_image_select',
							'heading'          => esc_html__( 'Banner style', 'cheshalo' ),
							'param_name'       => 'style',
							'value'            => array(
								esc_html__( 'Default', 'cheshalo' ) => 'default',
								esc_html__( 'Color mask', 'cheshalo' ) => 'mask',
								esc_html__( 'Mask with shadow', 'cheshalo' ) => 'shadow',
								esc_html__( 'Bordered', 'cheshalo' ) => 'border',
								esc_html__( 'Bordered background', 'cheshalo' ) => 'background',
								esc_html__( 'Content background', 'cheshalo' ) => 'content-background',
							),
							'images_value'     => array(
								'default'            => CHESHALO_ASSETS_IMAGES . '/settings/banner-style/default.png',
								'mask'               => CHESHALO_ASSETS_IMAGES . '/settings/banner-style/mask.png',
								'shadow'             => CHESHALO_ASSETS_IMAGES . '/settings/banner-style/shadow.png',
								'border'             => CHESHALO_ASSETS_IMAGES . '/settings/banner-style/border.png',
								'background'         => CHESHALO_ASSETS_IMAGES . '/settings/banner-style/background.png',
								'content-background' => CHESHALO_ASSETS_IMAGES . '/settings/banner-style/content-background.png',
							),
							'wood_tooltip'     => true,
							'hint'             => esc_html__( 'You can use some of our predefined styles for your banner content.', 'cheshalo' ),
							'edit_field_class' => 'vc_col-xs-12 vc_column banner-style',
						),
						array(
							'type'             => 'dropdown',
							'heading'          => esc_html__( 'Hover effect', 'cheshalo' ),
							'param_name'       => 'hover',
							'value'            => array(
								esc_html__( 'Zoom image', 'cheshalo' ) => 'zoom',
								esc_html__( 'Parallax', 'cheshalo' ) => 'parallax',
								esc_html__( 'Background', 'cheshalo' ) => 'background',
								esc_html__( 'Bordered', 'cheshalo' ) => 'border',
								esc_html__( 'Zoom reverse', 'cheshalo' ) => 'zoom-reverse',
								esc_html__( 'Disable', 'cheshalo' ) => 'none',
							),
							'hint'             => esc_html__( 'Set beautiful hover effects for your banner.', 'cheshalo' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'cheshalo_button_set',
							'heading'          => esc_html__( 'Color Scheme', 'cheshalo' ),
							'param_name'       => 'cheshalo_color_scheme',
							'value'            => array(
								esc_html__( 'Inherit', 'cheshalo' ) => '',
								esc_html__( 'Light', 'cheshalo' ) => 'light',
								esc_html__( 'Dark', 'cheshalo' )  => 'dark',
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'cheshalo_colorpicker',
							'heading'          => esc_html__( 'Content background color', 'cheshalo' ),
							'param_name'       => 'custom_content_bg_color',
							'css_args'         => array(
								'background-color' => array(
									' .wrapper-content-banner',
								),
							),
							'dependency'       => array(
								'element' => 'style',
								'value'   => array( 'content-background' ),
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						/**
						 * Extra.
						 */
						array(
							'type'       => 'cheshalo_title_divider',
							'holder'     => 'div',
							'title'      => esc_html__( 'Extra options', 'cheshalo' ),
							'param_name' => 'extra_divider',
						),
						array(
							'type'       => 'textfield',
							'heading'    => esc_html__( 'Extra class name', 'cheshalo' ),
							'param_name' => 'el_class',
							'hint'       => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'cheshalo' ),
						),
						/**
						 * Title.
						 */
						array(
							'type'       => 'cheshalo_title_divider',
							'holder'     => 'div',
							'title'      => esc_html__( 'Title', 'cheshalo' ),
							'group'      => esc_html__( 'Title and Subtitle', 'cheshalo' ),
							'param_name' => 'title_divider',
						),
						array(
							'type'       => 'textarea',
							'heading'    => esc_html__( 'Title', 'cheshalo' ),
							'param_name' => 'title',
							'holder'     => 'div',
							'group'      => esc_html__( 'Title and Subtitle', 'cheshalo' ),
						),
						array(
							'type'             => 'dropdown',
							'heading'          => esc_html__( 'Font', 'cheshalo' ),
							'group'            => esc_html__( 'Title and Subtitle', 'cheshalo' ),
							'param_name'       => 'title_font',
							'value'            => array(
								esc_html__( 'Default', 'cheshalo' ) => '',
								$text_font_title      => 'text',
								$primary_font_title   => 'primary',
								$secondary_font_title => 'alt',
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'dropdown',
							'heading'          => esc_html__( 'Title tag', 'cheshalo' ),
							'group'            => esc_html__( 'Title and Subtitle', 'cheshalo' ),
							'param_name'       => 'title_tag',
							'value'            => array(
								'h1'   => 'h1',
								'h2'   => 'h2',
								'h3'   => 'h3',
								'h4'   => 'h4',
								'h5'   => 'h5',
								'h6'   => 'h6',
								'p'    => 'p',
								'div'  => 'div',
								'span' => 'span',
							),
							'std'              => 'h4',
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'dropdown',
							'heading'          => esc_html__( 'Predefined title size', 'cheshalo' ),
							'group'            => esc_html__( 'Title and Subtitle', 'cheshalo' ),
							'param_name'       => 'title_size',
							'value'            => array(
								esc_html__( 'Default (22px)', 'cheshalo' ) => 'default',
								esc_html__( 'Small (16px)', 'cheshalo' ) => 'small',
								esc_html__( 'Large (26px)', 'cheshalo' ) => 'large',
								esc_html__( 'Extra Large (36px)', 'cheshalo' ) => 'extra-large',
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'dropdown',
							'heading'          => esc_html__( 'Font weight', 'cheshalo' ),
							'group'            => esc_html__( 'Title and Subtitle', 'cheshalo' ),
							'param_name'       => 'font_weight',
							'value'            => array(
								'' => '',
								esc_html__( 'Ultra-Light 100', 'cheshalo' ) => 100,
								esc_html__( 'Light 200', 'cheshalo' ) => 200,
								esc_html__( 'Book 300', 'cheshalo' ) => 300,
								esc_html__( 'Normal 400', 'cheshalo' ) => 400,
								esc_html__( 'Medium 500', 'cheshalo' ) => 500,
								esc_html__( 'Semi-Bold 600', 'cheshalo' ) => 600,
								esc_html__( 'Bold 700', 'cheshalo' ) => 700,
								esc_html__( 'Extra-Bold 800', 'cheshalo' ) => 800,
								esc_html__( 'Ultra-Bold 900', 'cheshalo' ) => 900,
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'cheshalo_responsive_size',
							'heading'          => esc_html__( 'Custom font size', 'cheshalo' ),
							'group'            => esc_html__( 'Title and Subtitle', 'cheshalo' ),
							'param_name'       => 'custom_title_size',
							'css_args'         => array(
								'font-size' => array(
									' .banner-title',
								),
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'cheshalo_responsive_size',
							'heading'          => esc_html__( 'Custom line height', 'cheshalo' ),
							'group'            => esc_html__( 'Title and Subtitle', 'cheshalo' ),
							'param_name'       => 'custom_title_line_height',
							'css_args'         => array(
								'line-height' => array(
									' .banner-title',
								),
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'       => 'cheshalo_empty_space',
							'param_name' => 'cheshalo_empty_space',
							'group'      => esc_html__( 'Title and Subtitle', 'cheshalo' ),
						),
						array(
							'type'             => 'cheshalo_colorpicker',
							'heading'          => esc_html__( 'Color', 'cheshalo' ),
							'group'            => esc_html__( 'Title and Subtitle', 'cheshalo' ),
							'param_name'       => 'custom_title_color',
							'css_args'         => array(
								'color' => array(
									' .banner-title',
								),
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						/**
						 * Subtitle.
						 */
						array(
							'type'       => 'cheshalo_title_divider',
							'holder'     => 'div',
							'title'      => esc_html__( 'Subtitle', 'cheshalo' ),
							'group'      => esc_html__( 'Title and Subtitle', 'cheshalo' ),
							'param_name' => 'subtitle_divider',
						),
						array(
							'type'       => 'textarea',
							'heading'    => esc_html__( 'Sub title', 'cheshalo' ),
							'param_name' => 'subtitle',
							'group'      => esc_html__( 'Title and Subtitle', 'cheshalo' ),
						),
						array(
							'type'             => 'dropdown',
							'heading'          => esc_html__( 'Font', 'cheshalo' ),
							'group'            => esc_html__( 'Title and Subtitle', 'cheshalo' ),
							'param_name'       => 'subtitle_font',
							'value'            => array(
								esc_html__( 'Default', 'cheshalo' ) => '',
								$text_font_title      => 'text',
								$primary_font_title   => 'primary',
								$secondary_font_title => 'alt',
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'dropdown',
							'heading'          => esc_html__( 'Font weight', 'cheshalo' ),
							'group'            => esc_html__( 'Title and Subtitle', 'cheshalo' ),
							'param_name'       => 'subtitle_font_weight',
							'value'            => array(
								'' => '',
								esc_html__( 'Ultra-Light 100', 'cheshalo' ) => 100,
								esc_html__( 'Light 200', 'cheshalo' ) => 200,
								esc_html__( 'Book 300', 'cheshalo' ) => 300,
								esc_html__( 'Normal 400', 'cheshalo' ) => 400,
								esc_html__( 'Medium 500', 'cheshalo' ) => 500,
								esc_html__( 'Semi-Bold 600', 'cheshalo' ) => 600,
								esc_html__( 'Bold 700', 'cheshalo' ) => 700,
								esc_html__( 'Extra-Bold 800', 'cheshalo' ) => 800,
								esc_html__( 'Ultra-Bold 900', 'cheshalo' ) => 900,
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'cheshalo_responsive_size',
							'heading'          => esc_html__( 'Size', 'cheshalo' ),
							'group'            => esc_html__( 'Title and Subtitle', 'cheshalo' ),
							'param_name'       => 'custom_subtitle_size',
							'css_args'         => array(
								'font-size' => array(
									' .banner-subtitle',
								),
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'cheshalo_responsive_size',
							'heading'          => esc_html__( 'Line height', 'cheshalo' ),
							'group'            => esc_html__( 'Title and Subtitle', 'cheshalo' ),
							'param_name'       => 'custom_subtitle_line_height',
							'css_args'         => array(
								'line-height' => array(
									' .banner-subtitle',
								),
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'       => 'cheshalo_empty_space',
							'param_name' => 'cheshalo_empty_space',
							'group'      => esc_html__( 'Title and Subtitle', 'cheshalo' ),
						),
						array(
							'type'             => 'cheshalo_dropdown',
							'heading'          => esc_html__( 'Predefined subtitle color scheme', 'cheshalo' ),
							'param_name'       => 'subtitle_color',
							'value'            => array(
								esc_html__( 'Default', 'cheshalo' ) => 'default',
								esc_html__( 'Primary', 'cheshalo' ) => 'primary',
								esc_html__( 'Alternative', 'cheshalo' ) => 'alt',
							),
							'style'            => array(
								'default' => '#f3f3f3',
								'primary' => cheshalo_get_color_value( 'primary-color', '#7eb934' ),
								'alt'     => cheshalo_get_color_value( 'secondary-color', '#fbbc34' ),
							),
							'group'            => esc_html__( 'Title and Subtitle', 'cheshalo' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'cheshalo_colorpicker',
							'heading'          => esc_html__( 'Custom color', 'cheshalo' ),
							'group'            => esc_html__( 'Title and Subtitle', 'cheshalo' ),
							'param_name'       => 'custom_subtitle_color',
							'css_args'         => array(
								'color' => array(
									' .banner-subtitle',
								),
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'cheshalo_image_select',
							'heading'          => esc_html__( 'Subtitle style', 'cheshalo' ),
							'group'            => esc_html__( 'Title and Subtitle', 'cheshalo' ),
							'param_name'       => 'subtitle_style',
							'value'            => array(
								esc_html__( 'Default', 'cheshalo' ) => 'default',
								esc_html__( 'Background', 'cheshalo' ) => 'background',
							),
							'images_value'     => array(
								'default'    => CHESHALO_ASSETS_IMAGES . '/settings/subtitle-style/default.png',
								'background' => CHESHALO_ASSETS_IMAGES . '/settings/subtitle-style/background.png',
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'cheshalo_colorpicker',
							'heading'          => esc_html__( 'Background color', 'cheshalo' ),
							'group'            => esc_html__( 'Title and Subtitle', 'cheshalo' ),
							'param_name'       => 'custom_subtitle_bg_color',
							'css_args'         => array(
								'background-color' => array(
									' .banner-subtitle',
								),
							),
							'dependency'       => array(
								'element' => 'subtitle_style',
								'value'   => array( 'background' ),
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						/**
						 * Content.
						 */
						array(
							'type'       => 'cheshalo_title_divider',
							'holder'     => 'div',
							'title'      => esc_html__( 'Content', 'cheshalo' ),
							'group'      => esc_html__( 'Content', 'cheshalo' ),
							'param_name' => 'content_divider',
						),
						array(
							'type'       => 'textarea_html',
							'holder'     => 'div',
							'heading'    => esc_html__( 'Banner content', 'cheshalo' ),
							'group'      => esc_html__( 'Content', 'cheshalo' ),
							'param_name' => 'content',
							'hint'       => esc_html__( 'Add here few words to your banner image.', 'cheshalo' ),
						),
						array(
							'type'             => 'dropdown',
							'heading'          => esc_html__( 'Text size', 'cheshalo' ),
							'group'            => esc_html__( 'Content', 'cheshalo' ),
							'param_name'       => 'content_text_size',
							'value'            => array(
								esc_html__( 'Default (14px)', 'cheshalo' ) => 'default',
								esc_html__( 'Medium (16px)', 'cheshalo' ) => 'medium',
								esc_html__( 'Large (18px)', 'cheshalo' ) => 'large',
								esc_html__( 'Custom', 'cheshalo' ) => 'custom',
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'cheshalo_colorpicker',
							'heading'          => esc_html__( 'Color', 'cheshalo' ),
							'group'            => esc_html__( 'Content', 'cheshalo' ),
							'param_name'       => 'custom_text_color',
							'css_args'         => array(
								'color' => array(
									' .banner-inner',
								),
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'cheshalo_responsive_size',
							'heading'          => esc_html__( 'Size', 'cheshalo' ),
							'group'            => esc_html__( 'Content', 'cheshalo' ),
							'param_name'       => 'custom_text_size',
							'css_args'         => array(
								'font-size' => array(
									' .banner-inner',
								),
							),
							'dependency'       => array(
								'element' => 'content_text_size',
								'value'   => array( 'custom' ),
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'cheshalo_responsive_size',
							'heading'          => esc_html__( 'Line height', 'cheshalo' ),
							'group'            => esc_html__( 'Content', 'cheshalo' ),
							'param_name'       => 'custom_text_line_height',
							'css_args'         => array(
								'line-height' => array(
									' .banner-inner',
								),
							),
							'dependency'       => array(
								'element' => 'content_text_size',
								'value'   => array( 'custom' ),
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						/**
						 * Button.
						 */
						array(
							'type'       => 'cheshalo_title_divider',
							'holder'     => 'div',
							'title'      => esc_html__( 'Button', 'cheshalo' ),
							'group'      => esc_html__( 'Button', 'cheshalo' ),
							'param_name' => 'button_divider',
						),
						array(
							'type'             => 'textfield',
							'heading'          => esc_html__( 'Button text', 'cheshalo' ),
							'param_name'       => 'btn_text',
							'group'            => esc_html__( 'Button', 'cheshalo' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'cheshalo_button_set',
							'heading'          => esc_html__( 'Button position', 'cheshalo' ),
							'param_name'       => 'btn_position',
							'value'            => array(
								esc_html__( 'Show on hover', 'cheshalo' ) => 'hover',
								esc_html__( 'Static', 'cheshalo' ) => 'static',
							),
							'group'            => esc_html__( 'Button', 'cheshalo' ),
							'dependency'       => array(
								'element'            => 'style',
								'value_not_equal_to' => array( 'content-background' ),
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'cheshalo_dropdown',
							'group'            => esc_html__( 'Button', 'cheshalo' ),
							'heading'          => esc_html__( 'Predefined button color', 'cheshalo' ),
							'param_name'       => 'btn_color',
							'value'            => array(
								esc_html__( 'Default', 'cheshalo' ) => 'default',
								esc_html__( 'Primary color', 'cheshalo' ) => 'primary',
								esc_html__( 'Alternative color', 'cheshalo' ) => 'alt',
								esc_html__( 'White', 'cheshalo' ) => 'white',
								esc_html__( 'Black', 'cheshalo' ) => 'black',
							),
							'style'            => array(
								'default' => '#f3f3f3',
								'primary' => cheshalo_get_color_value( 'primary-color', '#7eb934' ),
								'alt'     => cheshalo_get_color_value( 'secondary-color', '#fbbc34' ),
								'black'   => '#212121',
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'dropdown',
							'heading'          => esc_html__( 'Button size', 'cheshalo' ),
							'param_name'       => 'btn_size',
							'value'            => array(
								esc_html__( 'Default', 'cheshalo' ) => 'default',
								esc_html__( 'Extra Small', 'cheshalo' ) => 'extra-small',
								esc_html__( 'Small', 'cheshalo' ) => 'small',
								esc_html__( 'Large', 'cheshalo' ) => 'large',
								esc_html__( 'Extra Large', 'cheshalo' ) => 'extra-large',
							),
							'group'            => esc_html__( 'Button', 'cheshalo' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'cheshalo_image_select',
							'heading'          => esc_html__( 'Button style', 'cheshalo' ),
							'group'            => esc_html__( 'Button', 'cheshalo' ),
							'param_name'       => 'btn_style',
							'value'            => array(
								esc_html__( 'Flat', 'cheshalo' ) => 'default',
								esc_html__( 'Bordered', 'cheshalo' ) => 'bordered',
								esc_html__( 'Link button', 'cheshalo' ) => 'link',
								esc_html__( '3D', 'cheshalo' ) => '3d',
							),
							'images_value'     => array(
								'default'  => CHESHALO_ASSETS_IMAGES . '/settings/buttons/style/default.png',
								'bordered' => CHESHALO_ASSETS_IMAGES . '/settings/buttons/style/bordered.png',
								'link'     => CHESHALO_ASSETS_IMAGES . '/settings/buttons/style/link.png',
								'3d'       => CHESHALO_ASSETS_IMAGES . '/settings/buttons/style/3d.png',
							),
							'title'            => false,
							'std'              => 'default',
							'edit_field_class' => 'vc_col-xs-12 vc_column button-style',
						),
						array(
							'type'             => 'cheshalo_image_select',
							'heading'          => esc_html__( 'Button shape', 'cheshalo' ),
							'group'            => esc_html__( 'Button', 'cheshalo' ),
							'param_name'       => 'btn_shape',
							'value'            => array(
								esc_html__( 'Rectangle', 'cheshalo' ) => 'rectangle',
								esc_html__( 'Circle', 'cheshalo' ) => 'round',
								esc_html__( 'Round', 'cheshalo' ) => 'semi-round',
							),
							'images_value'     => array(
								'rectangle'  => CHESHALO_ASSETS_IMAGES . '/settings/buttons/shape/rectangle.jpeg',
								'round'      => CHESHALO_ASSETS_IMAGES . '/settings/buttons/shape/circle.jpeg',
								'semi-round' => CHESHALO_ASSETS_IMAGES . '/settings/buttons/shape/round.jpeg',
							),
							'dependency'       => array(
								'element'            => 'btn_style',
								'value_not_equal_to' => array( 'round', 'link' ),
							),
							'title'            => false,
							'std'              => 'rectangle',
							'edit_field_class' => 'vc_col-xs-12 vc_column button-shape',
						),
						array(
							'type'             => 'cheshalo_switch',
							'heading'          => esc_html__( 'Hide button on tablet', 'cheshalo' ),
							'group'            => esc_html__( 'Button', 'cheshalo' ),
							'param_name'       => 'hide_btn_tablet',
							'true_state'       => 'yes',
							'false_state'      => 'no',
							'default'          => 'no',
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'cheshalo_switch',
							'heading'          => esc_html__( 'Hide button on mobile', 'cheshalo' ),
							'group'            => esc_html__( 'Button', 'cheshalo' ),
							'param_name'       => 'hide_btn_mobile',
							'true_state'       => 'yes',
							'false_state'      => 'no',
							'default'          => 'no',
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						/**
						 * Layouts.
						 */
						array(
							'type'       => 'cheshalo_title_divider',
							'holder'     => 'div',
							'title'      => esc_html__( 'Layouts', 'cheshalo' ),
							'group'      => esc_html__( 'Layouts', 'cheshalo' ),
							'param_name' => 'positioning_divider',
						),
						array(
							'type'             => 'cheshalo_image_select',
							'heading'          => esc_html__( 'Content horizontal alignment', 'cheshalo' ),
							'group'            => esc_html__( 'Layouts', 'cheshalo' ),
							'param_name'       => 'horizontal_alignment',
							'value'            => array(
								esc_html__( 'Left', 'cheshalo' ) => 'left',
								esc_html__( 'Center', 'cheshalo' ) => 'center',
								esc_html__( 'Right', 'cheshalo' ) => 'right',
							),
							'images_value'     => array(
								'left'   => CHESHALO_ASSETS_IMAGES . '/settings/content-align/horizontal/left.png',
								'center' => CHESHALO_ASSETS_IMAGES . '/settings/content-align/horizontal/center.png',
								'right'  => CHESHALO_ASSETS_IMAGES . '/settings/content-align/horizontal/right.png',
							),
							'std'              => 'left',
							'wood_tooltip'     => true,
							'edit_field_class' => 'vc_col-sm-6 vc_column content-position',
						),
						array(
							'type'             => 'cheshalo_image_select',
							'heading'          => esc_html__( 'Content vertical alignment', 'cheshalo' ),
							'param_name'       => 'vertical_alignment',
							'group'            => esc_html__( 'Layouts', 'cheshalo' ),
							'value'            => array(
								esc_html__( 'Top', 'cheshalo' ) => 'top',
								esc_html__( 'Middle', 'cheshalo' ) => 'middle',
								esc_html__( 'Bottom', 'cheshalo' ) => 'bottom',
							),
							'images_value'     => array(
								'top'    => CHESHALO_ASSETS_IMAGES . '/settings/content-align/vertical/top.png',
								'middle' => CHESHALO_ASSETS_IMAGES . '/settings/content-align/vertical/middle.png',
								'bottom' => CHESHALO_ASSETS_IMAGES . '/settings/content-align/vertical/bottom.png',
							),
							'std'              => 'top',
							'wood_tooltip'     => true,
							'edit_field_class' => 'vc_col-sm-6 vc_column content-position',
						),
						array(
							'type'             => 'cheshalo_image_select',
							'heading'          => esc_html__( 'Text alignment', 'cheshalo' ),
							'group'            => esc_html__( 'Layouts', 'cheshalo' ),
							'param_name'       => 'text_alignment',
							'value'            => array(
								esc_html__( 'Left', 'cheshalo' ) => 'left',
								esc_html__( 'Center', 'cheshalo' ) => 'center',
								esc_html__( 'Right', 'cheshalo' ) => 'right',
							),
							'images_value'     => array(
								'center' => CHESHALO_ASSETS_IMAGES . '/settings/align/center.jpg',
								'left'   => CHESHALO_ASSETS_IMAGES . '/settings/align/left.jpg',
								'right'  => CHESHALO_ASSETS_IMAGES . '/settings/align/right.jpg',
							),
							'std'              => 'left',
							'wood_tooltip'     => true,
							'edit_field_class' => 'vc_col-sm-6 vc_column title-align',
						),
						array(
							'type'             => 'dropdown',
							'heading'          => esc_html__( 'Content width', 'cheshalo' ),
							'group'            => esc_html__( 'Layouts', 'cheshalo' ),
							'param_name'       => 'content_width',
							'value'            => array(
								'100%' => '100',
								'90%'  => '90',
								'80%'  => '80',
								'70%'  => '70',
								'60%'  => '60',
								'50%'  => '50',
								'40%'  => '40',
								'30%'  => '30',
								'20%'  => '20',
								'10%'  => '10',
							),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						array(
							'type'             => 'cheshalo_switch',
							'heading'          => esc_html__( 'Increase spaces', 'cheshalo' ),
							'group'            => esc_html__( 'Layouts', 'cheshalo' ),
							'param_name'       => 'increase_spaces',
							'hint'             => esc_html__( 'Suggest to use this option if you have large banners. Padding will be set in percentage to your screen width.', 'cheshalo' ),
							'true_state'       => 'yes',
							'false_state'      => 'no',
							'default'          => 'no',
							'edit_field_class' => 'vc_col-sm-6 vc_column',
						),
						/**
						 * Deprecated.
						 */
						array(
							'type'       => 'textfield',
							'heading'    => esc_html__( 'Title desktop text size ( > 1024px )', 'cheshalo' ),
							'param_name' => 'title_desktop_text_size',
							'hint'       => esc_html__( 'Only number without px.', 'cheshalo' ),
							'group'      => esc_html__( 'Custom size', 'cheshalo' ),
							'dependency' => array(
								'element' => 'title_size',
								'value'   => array( 'custom' ),
							),
						),
						array(
							'type'       => 'textfield',
							'heading'    => esc_html__( 'Title tablet text size ( < 1024px )', 'cheshalo' ),
							'param_name' => 'title_tablet_text_size',
							'hint'       => esc_html__( 'Only number without px.', 'cheshalo' ),
							'group'      => esc_html__( 'Custom size', 'cheshalo' ),
							'dependency' => array(
								'element' => 'title_size',
								'value'   => array( 'custom' ),
							),
						),
						array(
							'type'       => 'textfield',
							'heading'    => esc_html__( 'Title mobile text size ( < 767px )', 'cheshalo' ),
							'param_name' => 'title_mobile_text_size',
							'hint'       => esc_html__( 'Only number without px.', 'cheshalo' ),
							'group'      => esc_html__( 'Custom size', 'cheshalo' ),
							'dependency' => array(
								'element' => 'title_size',
								'value'   => array( 'custom' ),
							),
						),
						/**
						 * Subtitle custom size.
						 */
						array(
							'type'       => 'textfield',
							'heading'    => esc_html__( 'Subtitle desktop text size ( > 1024px )', 'cheshalo' ),
							'param_name' => 'subtitle_desktop_text_size',
							'hint'       => esc_html__( 'Only number without px.', 'cheshalo' ),
							'group'      => esc_html__( 'Custom size', 'cheshalo' ),
							'dependency' => array(
								'element' => 'title_size',
								'value'   => array( 'custom' ),
							),
						),
						array(
							'type'       => 'textfield',
							'heading'    => esc_html__( 'Subtitle tablet text size ( < 1024px )', 'cheshalo' ),
							'param_name' => 'subtitle_tablet_text_size',
							'hint'       => esc_html__( 'Only number without px.', 'cheshalo' ),
							'group'      => esc_html__( 'Custom size', 'cheshalo' ),
							'dependency' => array(
								'element' => 'title_size',
								'value'   => array( 'custom' ),
							),
						),
						array(
							'type'       => 'textfield',
							'heading'    => esc_html__( 'Subtitle mobile text size ( < 767px )', 'cheshalo' ),
							'param_name' => 'subtitle_mobile_text_size',
							'hint'       => esc_html__( 'Only number without px.', 'cheshalo' ),
							'group'      => esc_html__( 'Custom size', 'cheshalo' ),
							'dependency' => array(
								'element' => 'title_size',
								'value'   => array( 'custom' ),
							),
						),
					),
				)
			);
		}

		/**
		 * This method render this widget.
		 *
		 * @param array $args general settings for this widget.
		 * @param array $instance the value of the options for output.
		 */
		public function widget( $args, $instance ) {
			if ( $this->is_widget_preview() ) {
				return;
			}

			$instance['custom_height'] = 'yes';

			extract( $args );

			echo wp_kses_post( $before_widget );

			echo cheshalo_shortcode_promo_banner( $instance, $instance['content'] );

			echo wp_kses_post( $after_widget );
		}
	}
}
